%define lib_major	4
%define lib_name_orig	%mklibname ssh
%define lib_name	%mklibname ssh %{lib_major}
%define dev_name	%mklibname ssh -d

Summary:	C library to authenticate in a simple manner to one or more SSH servers
Name:		libssh
Epoch:		1
Version:	0.9.6
Release:	%mkrel 1
Group:		System/Libraries
License:	LGPLv2.1+
URL:		http://www.libssh.org
Source0:	http://git.libssh.org/projects/libssh.git/snapshot/%{name}-%{version}.tar.gz

BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	pkgconfig(mit-krb5-gssapi)
BuildRequires:	pkgconfig(openssl) >= 1.1
BuildRequires:	pkgconfig(zlib)
BuildRequires:	libgcrypt-devel
BuildRequires:	libpcap-devel

%description
The ssh library was designed to be used by programmers needing a working 
SSH implementation by the mean of a library. The complete control of the 
client is made by the programmer. With libssh, you can remotely execute 
programs, transfer files, use a secure and transparent tunnel for your 
remote programs. With its Secure FTP implementation, you can play with 
remote files easily, without third-party programs others than libcrypto 
(from openssl). libssh features :

    * Full C library functions for manipulating a client-side SSH
      connection
    * Lesser GPL licensing -SSH2 protocol compliant
    * Fully configurable sessions
    * Support for AES-128,AES-192,AES-256,blowfish, in cbc mode
    * Use multiple SSH connections in a same process, at same time
    * Use multiple channels in the same connection
    * Thread safety when using different sessions at same time
    * Basic but correct SFTP implementation (secure file transfer)
    * RSA and DSS server public key supported
    * Compression support (with zlib)
    * Public key (RSA and DSS), password and keyboard-interactive
      authentication
    * Complete documentation about its API
    * Runs and tested under amd64, x86, arm, sparc32, ppc under Linux,
      BSD, MacosX and Solaris
    * A developer listening to you
    * It's free (LGPL)!

#--------------------------------------------------------------------


%package -n	%{lib_name}
Summary:	Main library for %{name}
Group:		System/Libraries

%description -n	%{lib_name}
The ssh library was designed to be used by programmers needing a working
SSH implementation by the mean of a library. The complete control of the
client is made by the programmer. With libssh, you can remotely execute
programs, transfer files, use a secure and transparent tunnel for your
remote programs. With its Secure FTP implementation, you can play with
remote files easily, without third-party programs others than libcrypto
(from openssl).

%files -n %{lib_name}
%{_libdir}/*.so.%{lib_major}{,.*}

#--------------------------------------------------------------------

%package -n	%{dev_name}
Summary:	Development files for %{name}
Group:		System/Libraries
Requires:	%{lib_name} = %{epoch}:%{version}-%{release}
Provides:	ssh-devel = %{epoch}:%{version}-%{release}
Provides:	libssh-devel = %{epoch}:%{version}-%{release}

%description -n	%{dev_name}
This package contains the development files for %{name}.

%files -n %{dev_name}
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/*

#--------------------------------------------------------------------

%prep
%setup -q
%autopatch -p1

%build
%cmake -DWITH_GCRYPT=ON -DWITH_PCAP=ON
%cmake_build

%install
%cmake_install


%changelog
* Mon Sep 06 2021 ns80 <ns80> 1:0.9.6-1.mga8
+ Revision: 1744378
- new version 0.9.6 for CVE-2021-3634 (mga#29419)

* Thu Sep 17 2020 joequant <joequant> 1:0.9.5-1.mga8
+ Revision: 1628204
- update to 0.9.5 / security patch upstreamed

* Wed Aug 05 2020 daviddavid <daviddavid> 1:0.9.4-2.mga8
+ Revision: 1611257
- add upstream patch to fix CVE-2020-16135 (mga#27036)

* Thu Apr 09 2020 daviddavid <daviddavid> 1:0.9.4-1.mga8
+ Revision: 1565877
- new version: 0.9.4, fixes CVE-2020-1730 (mga#26462)

* Tue Feb 18 2020 umeabot <umeabot> 1:0.9.3-2.mga8
+ Revision: 1539721
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Fri Dec 13 2019 daviddavid <daviddavid> 1:0.9.3-1.mga8
+ Revision: 1466106
- new version: 0.9.3, fixes CVE-2019-14889 (mga#25865)

* Fri Nov 08 2019 daviddavid <daviddavid> 1:0.9.2-1.mga8
+ Revision: 1458729
- new version: 0.9.2

* Thu Oct 31 2019 daviddavid <daviddavid> 1:0.9.1-1.mga8
+ Revision: 1457065
- new version: 0.9.1

* Thu Jul 04 2019 daviddavid <daviddavid> 1:0.9.0-2.mga8
+ Revision: 1418527
- do not ignore keys from known_hosts when SSH_OPTIONS_HOSTKEYS is set

* Thu Jul 04 2019 daviddavid <daviddavid> 1:0.9.0-1.mga8
+ Revision: 1418308
- new version: 0.9.0

* Thu Feb 28 2019 daviddavid <daviddavid> 1:0.8.7-1.mga7
+ Revision: 1370457
- new version: 0.8.7

* Sat Dec 29 2018 luigiwalser <luigiwalser> 1:0.8.6-1.mga7
+ Revision: 1346490
- 0.8.6

* Mon Oct 29 2018 daviddavid <daviddavid> 1:0.8.5-1.mga7
+ Revision: 1326526
- new version: 0.8.5

* Tue Oct 16 2018 daviddavid <daviddavid> 1:0.8.4-1.mga7
+ Revision: 1320998
- new version: 0.8.4, fixes CVE-2018-10933 (mga#23711)

* Wed Oct 03 2018 daviddavid <daviddavid> 1:0.8.3-1.mga7
+ Revision: 1317220
- new version: 0.8.3

* Sun Sep 23 2018 umeabot <umeabot> 1:0.8.1-2.mga7
+ Revision: 1299169
- Mageia 7 Mass Rebuild

* Wed Aug 15 2018 daviddavid <daviddavid> 1:0.8.1-1.mga7
+ Revision: 1251699
- new version: 0.8.1

* Tue May 02 2017 luigiwalser <luigiwalser> 1:0.7.5-1.mga6
+ Revision: 1098253
- 0.7.5

* Sun Feb 12 2017 luigiwalser <luigiwalser> 1:0.7.4-1.mga6
+ Revision: 1085836
- 0.7.4

* Tue Feb 23 2016 pterjan <pterjan> 1:0.7.3-1.mga6
+ Revision: 977352
- Update to 0.7.3 (CVE-2016-0739)

* Fri Jan 01 2016 luigiwalser <luigiwalser> 1:0.7.2-1.mga6
+ Revision: 917797
- 0.7.2

* Thu Sep 10 2015 fwang <fwang> 1:0.6.5-2.mga6
+ Revision: 875366
- rebuild for new libgcrypt

* Wed May 06 2015 luigiwalser <luigiwalser> 1:0.6.5-1.mga5
+ Revision: 821333
- 0.6.5 (fixes CVE-2015-3146)
- remove upstreamed patches

* Mon Jan 05 2015 luigiwalser <luigiwalser> 1:0.6.4-1.mga5
+ Revision: 808703
- 0.6.4 (fixes CVE-2014-8132)
- add upstream patches to fix bug and build error

* Wed Oct 15 2014 umeabot <umeabot> 1:0.6.3-3.mga5
+ Revision: 747112
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:0.6.3-2.mga5
+ Revision: 681798
- Mageia 5 Mass Rebuild

* Wed Mar 05 2014 luigiwalser <luigiwalser> 1:0.6.3-1.mga5
+ Revision: 599978
- 0.6.3 (fixes CVE-2014-0017)

* Sat Feb 15 2014 dams <dams> 1:0.6.1-1.mga5
+ Revision: 591816
- new version 0.6.1

* Fri Jan 17 2014 luigiwalser <luigiwalser> 1:0.6.0-1.mga5
+ Revision: 566765
- 0.6.0

* Sat Oct 19 2013 umeabot <umeabot> 1:0.5.5-2.mga4
+ Revision: 530650
- Mageia 4 Mass Rebuild

* Fri Jul 26 2013 sander85 <sander85> 1:0.5.5-1.mga4
+ Revision: 458705
- New version: 0.5.5

* Tue Jan 29 2013 luigiwalser <luigiwalser> 1:0.5.4-1.mga3
+ Revision: 393089
- 0.5.4 (fixes CVE-2013-0176)

* Sat Jan 12 2013 umeabot <umeabot> 1:0.5.3-2.mga3
+ Revision: 358208
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Nov 26 2012 luigiwalser <luigiwalser> 1:0.5.3-1.mga3
+ Revision: 322162
- 0.5.3 (fixes CVE-2012-4559 and CVE-2012-466[0-2])

* Sat Sep 17 2011 fwang <fwang> 1:0.5.2-1.mga2
+ Revision: 144506
- new version 0.5.2

* Wed Sep 14 2011 tv <tv> 1:0.5.1-1.mga2
+ Revision: 143340
- fix file list
- new release

* Mon Jul 04 2011 dmorgan <dmorgan> 1:0.5.0-1.mga2
+ Revision: 118347
- Fix spec file
  Clean spec file

* Sat Jan 15 2011 mikala <mikala> 1:0.4.7-1.mga1
+ Revision: 18635
- Remove BuildRoot
- imported package libssh


* Sun Jan 02 2011 Lev Givon <lev@mandriva.org> 1:0.4.7-1mdv2011.0
+ Revision: 627541
- Update to 0.4.7.

* Tue Sep 07 2010 Funda Wang <fwang@mandriva.org> 1:0.4.6-1mdv2011.0
+ Revision: 576421
- update to new version 0.4.6

  + Matthew Dawkins <mattydaw@mandriva.org>
    - new version 0.4.5

* Sat Jul 17 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1:0.4.4-2mdv2011.0
+ Revision: 554541
- spec file clean
  build against libgcrypt and libpcap

* Thu Jul 15 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1:0.4.4-1mdv2011.0
+ Revision: 553704
- update to new version 0.4.4

* Thu Apr 08 2010 Eugeni Dodonov <eugeni@mandriva.com> 1:0.4.2-2mdv2010.1
+ Revision: 533131
- Rebuild for new openssl

* Mon Mar 22 2010 Emmanuel Andry <eandry@mandriva.org> 1:0.4.2-1mdv2010.1
+ Revision: 526614
- New version 0.4.2
- fix license

* Mon Feb 15 2010 Frederik Himpe <fhimpe@mandriva.org> 1:0.4.1-1mdv2010.1
+ Revision: 506355
- update to new version 0.4.1

* Fri Dec 11 2009 Funda Wang <fwang@mandriva.org> 1:0.4.0-1mdv2010.1
+ Revision: 476387
- new version 0.4.0

* Thu Dec 03 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1:0.3.92-1mdv2010.1
+ Revision: 472802
- Update to version 0.3.92

* Wed Sep 16 2009 Frederik Himpe <fhimpe@mandriva.org> 1:0.3.4-2mdv2010.0
+ Revision: 443612
- Really update to new version 0.3.4
- Remove literal patch: integrated upstream
- update to new version 0.3.4

* Wed Aug 19 2009 Frederik Himpe <fhimpe@mandriva.org> 1:0.3.3-1mdv2010.0
+ Revision: 418098
- update to new version 0.3.3

* Mon Aug 17 2009 Helio Chissini de Castro <helio@mandriva.com> 1:0.3.0-1mdv2010.0
+ Revision: 417281
- Update to current build cmake based. new version is required to next sftp/ftp
  kioslave in kde
- Add literal wstring patch

* Sun Jul 27 2008 Thierry Vignaud <tv@mandriva.org> 0:0.20-6mdv2009.0
+ Revision: 250585
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sat Jan 19 2008 Anssi Hannula <anssi@mandriva.org> 0:0.20-4mdv2008.1
+ Revision: 155080
- fix libification

* Fri Jan 18 2008 David Walluck <walluck@mandriva.org> 0:0.20-3mdv2008.1
+ Revision: 154528
- fix libname

* Tue Jan 15 2008 David Walluck <walluck@mandriva.org> 0:0.20-2mdv2008.1
+ Revision: 152023
- SVN r132

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed May 02 2007 David Walluck <walluck@mandriva.org> 0:0.20-1mdv2008.0
+ Revision: 20578
- change version to 0.20 from 0.2 so that it's greater than 0.11


* Mon Oct 16 2006 David Walluck <walluck@mandriva.org> 0.2-0.20060921.2mdv2006.0
+ Revision: 65309
+ Status: not released
- bump release

* Sun Oct 15 2006 David Walluck <walluck@mandriva.org> 0:0.2-0.20060921.1mdv2007.1
+ Revision: 64924
- Import libssh

* Thu Sep 21 2006 David Walluck <walluck@mandriva.org> 0:0.2-0.20060901.1mdv2007.0
- release

